==> haskell-storable-tuple-0.0.3.3-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-tuple
version: 0.0.3.3
id: storable-tuple-0.0.3.3-HSzcPXIUGrrAVhHHeujbmn
key: storable-tuple-0.0.3.3-HSzcPXIUGrrAVhHHeujbmn
license: BSD-3-Clause
maintainer: Henning Thielemann <storable@henning-thielemann.de>
author: Henning Thielemann <storable@henning-thielemann.de>
stability: Experimental
homepage: http://code.haskell.org/~thielema/storable-tuple/
synopsis: Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
category: Data, Foreign
abi: 13befce4251d0ec103e597ff5e3a187c
exposed: True
exposed-modules:
    Foreign.Storable.Tuple
import-dirs: /usr/lib/ghc-8.6.4/site-local/storable-tuple-0.0.3.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/storable-tuple-0.0.3.3
hs-libraries: HSstorable-tuple-0.0.3.3-HSzcPXIUGrrAVhHHeujbmn
depends:
    base-4.12.0.0 base-orphans-0.8.1-7pMKcJWz5xk6HSPJDBRBYU
    storable-record-0.0.4-FWs9yvrzelO6WCzQBkZBUX
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock
haddock-html: /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-tuple-0.0.3.3-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-tuple
version: 0.0.3.3
id: storable-tuple-0.0.3.3-68UnGxgk5RU574iBov3pNa
key: storable-tuple-0.0.3.3-68UnGxgk5RU574iBov3pNa
license: BSD-3-Clause
maintainer: Henning Thielemann <storable@henning-thielemann.de>
author: Henning Thielemann <storable@henning-thielemann.de>
stability: Experimental
homepage: http://code.haskell.org/~thielema/storable-tuple/
synopsis: Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
category: Data, Foreign
abi: f8c1be98087f620ef9bf31e6bf69f6fd
exposed: True
exposed-modules:
    Foreign.Storable.Tuple
import-dirs: /usr/lib/ghc-8.6.4/site-local/storable-tuple-0.0.3.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/storable-tuple-0.0.3.3
hs-libraries: HSstorable-tuple-0.0.3.3-68UnGxgk5RU574iBov3pNa
depends:
    base-4.12.0.0 base-orphans-0.8.1-F7WXvYe1At7CE5V4l7fyKU
    storable-record-0.0.4-FWs9yvrzelO6WCzQBkZBUX
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock
haddock-html: /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
